Module renderer

Module renderer 

Chrome/Chromium backend via Chrome DevTools Protocol (CDP).

Launches Chrome in headless mode, captures screenshots via CDP, and renders them to native tao windows using Windows GDI.

Structs

CefRenderer